@@ -23,12 +23,13 @@
 #include "da_transaction.h"
 
 typedef struct _archive		Archive;
-typedef struct _budget		Budget;
+//typedef struct _budget		Budget;
 
 typedef struct _filter	Filter;
 typedef struct _carcost	CarCost;
 
 
+/*
 struct _budget
 {
 	guint	key;
@@ -37,6 +38,7 @@ struct _budget
 	guint	year;
 	gdouble	value[13];
 };
+*/
 
 #define BF_CUSTOM	(1<<2)
 
@@ -58,7 +60,7 @@ struct _archive
 	gushort	limit;
 };
 
-
+/*
 struct _investment
 {
 	guint	date;
@@ -71,6 +73,7 @@ struct _investment
 	gchar	*symbol;
 	gchar	*note;
 };
+*/
 
 
 /* secondary structures */
@@ -80,6 +83,8 @@ struct _filter
 	guint		option[FILTER_MAX];
 	guint		mindate, maxdate;
 	gushort		range, month, year;
+	gboolean	validated;
+	gboolean	reminded;
 	gboolean	forceadd;
 	gboolean	forcechg;
 	gboolean	paymode[NUM_PAYMODE_MAX];
