@@ -459,7 +459,7 @@ gint page;
 
 	if(payment == PAYMODE_CHEQUE)
 		page = 1;
-	if(payment == PAYMODE_PERSTRANSFERT)
+	if(payment == PAYMODE_PERSTRANSFER)
 		page = 2;
 
 	DB( g_printf(" payment: %d, page: %d\n", payment, page) );
