@@ -63,6 +63,8 @@ struct deffilter_data
 
 	GtkWidget	*PO_mindate, *PO_maxdate;
 
+	GtkWidget	*CM_validated, *CM_reminded;
+
 	GtkWidget	*CM_forceadd, *CM_forcechg;
 
 	GtkWidget	*CM_paymode[NUM_PAYMODE_MAX];
@@ -127,6 +129,9 @@ gint i;
 
 */
 
+	flt->validated = TRUE;
+	flt->reminded = TRUE;
+
 	flt->forceadd = FALSE;
 	flt->forcechg = FALSE;
 
@@ -138,7 +143,8 @@ gint i;
 
 gint filter_test(Filter *flt, Operation *ope)
 {
-gint insert, count;
+gint insert;
+DB( gint count );
 Account *accitem;
 Payee *payitem;
 Category *catitem;
@@ -146,11 +152,9 @@ Category *catitem;
 	//DB( g_printf("(filter) test\n") );
 
 	insert = 1;
-	count = 0;
+	DB( count = 0 );
 
 /*** start filtering ***/
-	if( ope->flags & OF_REMIND )
-		goto end;
 
 	/* add/change force */
 	if(flt->forceadd == TRUE && (ope->flags & OF_ADDED))
@@ -162,7 +166,7 @@ Category *catitem;
 /* date */
 	if(flt->option[FILTER_DATE]) {
 		insert = ( (ope->date >= flt->mindate) && (ope->date <= flt->maxdate) ) ? 1 : 0;
-		count++;
+		DB( count++ );
 		if(flt->option[FILTER_DATE] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
@@ -173,7 +177,7 @@ Category *catitem;
 		if(accitem)
 		{	
 			insert = ( accitem->filter == TRUE ) ? 1 : 0;
-			count++;
+			DB( count++ );
 			if(flt->option[FILTER_ACCOUNT] == 2) insert ^= 1;
 		}
 	}
@@ -185,7 +189,7 @@ Category *catitem;
 		if(payitem)
 		{
 			insert = ( payitem->filter == TRUE ) ? 1 : 0;
-			count++;
+			DB( count++ );
 			if(flt->option[FILTER_PAYEE] == 2) insert ^= 1;
 		}
 	}
@@ -197,7 +201,7 @@ Category *catitem;
 		if(catitem)
 		{
 			insert = ( catitem->filter == TRUE ) ? 1 : 0;
-			count++;
+			DB( count++ );
 			if(flt->option[FILTER_CATEGORY] == 2) insert ^= 1;
 		}
 	}
@@ -205,8 +209,16 @@ Category *catitem;
 
 /* status */
 	if(flt->option[FILTER_STATUS]) {
-		insert = ( ope->flags & OF_VALID ) ? 1 : 0;
-		count++;
+	gint insert1 = 0, insert2 = 0;
+	
+		if(flt->validated)
+			insert1 = ( ope->flags & OF_VALID ) ? 1 : 0;
+		if(flt->reminded)
+			insert2 = ( ope->flags & OF_REMIND ) ? 1 : 0;
+		
+		insert = insert1 | insert2;
+
+		DB( count++ );
 		if(flt->option[FILTER_STATUS] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
@@ -214,7 +226,7 @@ Category *catitem;
 /* paymode */
 	if(flt->option[FILTER_PAYMODE]) {
 		insert = ( flt->paymode[ope->paymode] == TRUE) ? 1 : 0;
-		count++;
+		DB( count++ );
 		if(flt->option[FILTER_PAYMODE] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
@@ -222,7 +234,7 @@ Category *catitem;
 /* amount */
 	if(flt->option[FILTER_AMOUNT]) {
 		insert = ( (ope->amount >= flt->minamount) && (ope->amount <= flt->maxamount) ) ? 1 : 0;
-		count++;
+		DB( count++ );
 		if(flt->option[FILTER_AMOUNT] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
@@ -408,6 +420,12 @@ gboolean sensitive;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
+	// status
+	active = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_option[FILTER_STATUS]));
+	sensitive = active == 0 ? FALSE : TRUE;
+	gtk_widget_set_sensitive(data->CM_validated, sensitive);
+	gtk_widget_set_sensitive(data->CM_reminded, sensitive);
+
 	// date
 	active = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_option[FILTER_DATE]));
 	sensitive = active == 0 ? FALSE : TRUE;
@@ -498,6 +516,9 @@ gint i;
 
 	//status
 		DB( g_printf(" status\n") );
+		data->filter->validated = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_validated));
+		data->filter->reminded  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_reminded));
+
 		data->filter->forceadd = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_forceadd));
 		data->filter->forcechg = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_forcechg));
 
@@ -644,6 +665,9 @@ void deffilter_set(struct deffilter_data *data)
 
 	//status
 		DB( g_printf(" status\n") );
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_validated), data->filter->validated);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_reminded), data->filter->reminded);
+
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_forceadd), data->filter->forceadd);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_forcechg), data->filter->forcechg);
 
@@ -1020,7 +1044,7 @@ gint row, i;
 		gtk_misc_set_padding (GTK_MISC (label), HB_BOX_SPACING, 0);
 		gtk_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
-		label = make_label(_("Validated:"), 0, 0.5);
+		label = make_label(_("_Option:"), 0, 0.5);
 		//----------------------------------------- l, r, t, b
 		gtk_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
@@ -1028,6 +1052,16 @@ gint row, i;
 		data->CY_option[FILTER_STATUS] = make_cycle(label, CYA_NAINOUT);
 		gtk_table_attach (GTK_TABLE (table), data->CY_option[FILTER_STATUS], 2, 3, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
 
+		row++;
+		widget = gtk_check_button_new_with_mnemonic (_("validated"));
+		gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+		data->CM_validated = widget;
+		
+		row++;
+		widget = gtk_check_button_new_with_mnemonic (_("remind"));
+		gtk_table_attach (GTK_TABLE (table), widget, 2, 3, row, row+1, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
+		data->CM_reminded = widget;
+
 		row++;
 		label = make_label(_("Force:"), 0, 0.5);
 		//----------------------------------------- l, r, t, b
@@ -1226,6 +1260,7 @@ GtkWidget *window, *mainbox, *notebook, *label, *page;
 	//maybe later
 
 	/* signal connect */
+    g_signal_connect (data.CY_option[FILTER_STATUS]  , "changed", G_CALLBACK (deffilter_option_update), NULL);
     g_signal_connect (data.CY_option[FILTER_DATE]    , "changed", G_CALLBACK (deffilter_option_update), NULL);
     g_signal_connect (data.CY_option[FILTER_AMOUNT]  , "changed", G_CALLBACK (deffilter_option_update), NULL);
     g_signal_connect (data.CY_option[FILTER_PAYMODE] , "changed", G_CALLBACK (deffilter_option_update), NULL);
