@@ -170,7 +170,7 @@ gint active;
 
 	/* look and store for a child transfer operation */
 	child = NULL;	
-	if( entry->paymode == PAYMODE_PERSTRANSFERT && data->type == OPERATION_EDIT_MODIFY )
+	if( entry->paymode == PAYMODE_PERSTRANSFER && data->type == OPERATION_EDIT_MODIFY )
 	{
 		DB( g_print(" search: %d %s %f %d=>%d\n", entry->date, entry->wording, entry->amount, entry->account, entry->dst_account) );
 
@@ -209,7 +209,7 @@ gint active;
 	entry->amount = value;
 
 	/* for internal transfer add, amount must be expense */
-	if( entry->paymode == PAYMODE_PERSTRANSFERT && data->type == OPERATION_EDIT_ADD )
+	if( entry->paymode == PAYMODE_PERSTRANSFER && data->type == OPERATION_EDIT_ADD )
 	{
 		if( entry->amount > 0 )
 			entry->amount *= -1;
@@ -399,7 +399,7 @@ gint page;
 
 	if(payment == PAYMODE_CHEQUE)
 		page = 1;
-	if(payment == PAYMODE_PERSTRANSFERT)
+	if(payment == PAYMODE_PERSTRANSFER)
 		page = 2;
 
 	DB( g_printf(" payment: %d, page: %d\n", payment, page) );
@@ -447,7 +447,7 @@ gboolean sensitive;
 	if(kacc == 0) sensitive = FALSE;
 
 	/* coherent seizure */
-	if( gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode)) == PAYMODE_PERSTRANSFERT )
+	if( gtk_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode)) == PAYMODE_PERSTRANSFER )
 	{
 
 		kdst = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX_ENTRY(data->PO_accto));
@@ -491,7 +491,7 @@ gboolean sensitive, bool;
 	sensitive = TRUE;
 	if( data->type == OPERATION_EDIT_MODIFY && data->ope !=NULL )
 	{
-		if( data->ope->paymode == PAYMODE_PERSTRANSFERT )
+		if( data->ope->paymode == PAYMODE_PERSTRANSFER )
 		{
 			sensitive = FALSE;
 		}
