@@ -213,18 +213,20 @@ static EuroParams euro_params[] =
 /* 2007 */
 	{ "SIT", "Slovenia"      , 239.640	, "tol", ""    , ",", ".", 2  },	//
 /* 2008 */
-	{ "EEK", "Estonia"       , 15.6466  , ""   , "kr"  , ",", " ", 2  },	//
-	{ "LVL", "Lettonia"      , 0.702804 , ""   , ""    , ",", "" , 2  },	//
 	{ "CYP", "Cyprus"        , 0.585274 , ""   , ""    , ",", "" , 2  },	//
 	{ "MTL", "Malta"         , 0.429300 , ""   , ""    , ",", "" , 2  },	//
 /* 2009 */
-//	{ "SKK", "Slovaquia"     , 38.4550  , ""   , "Sk"  , ",", " ", 2  },	//
-//	{ "BGN", "Bulgaria"      , 1.00000	, "лв.", ""    , ",", " ", 2  },	//
+	{ "SKK", "Slovaquia"     , 38.4550  , ""   , "Sk"  , ",", " ", 2  },	//
 /* 2010 */
-//	{ "CZK", "Czech republic", 1.00000	, ""   , "Kč"  , ",", " ", 2  },	//
-//	{ "HUF", "Hungary"       , 1.00000	, "Ft" , ""    , ",", " ", 2  },	//
+	{ "EEK", "Estonia"       , 15.6466  , ""   , "kr"  , ",", " ", 2  },	//
+	{ "LVL", "Lettonia"      , 0.702804 , ""   , "lat.", ",", "" , 2  },	//
+	{ "BGN", "Bulgaria"      , 1.95583	, "лв.", ""    , ",", " ", 2  },	// non-fixé
+	{ "LTL", "Lithuania"     , 3.45280	, "Lt.", ""    , ",", "" , 2  },
 /* 2012 */
-//	{ "RON", "Romania"       , 1.00000	, ""   , "LEI" , ",", ".", 2  },	//
+	{ "CZK", "Czech republic", 28.36	, ""   , "Kč"  , ",", " ", 2  },	// non-fixé
+/* 2013 */
+	{ "HUF", "Hungary"       , 261.51	, "Ft" , ""    , ",", " ", 2  },	// non-fixé
+	{ "RON", "Romania"       , 3.5155	, ""   , "LEI" , ",", ".", 2  },	// non-fixé
 
 //	{ "   ", ""    , 1.00000	, ""   , ""  , ",", "", 2  },
 };
