@@ -49,7 +49,6 @@ extern struct Preferences *PREFS;
 //debug
 #define UI 1
 
-
 enum
 {
 	ACTION_ACCOUNT_ADD,
@@ -137,6 +136,7 @@ static void account_toggle(GtkWidget *widget, gpointer user_data);
 static void account_update(GtkWidget *widget, gpointer user_data);
 
 static void account_export_csv(GtkWidget *widget, gpointer user_data);
+
 static void account_make_archive(GtkWidget *widget, gpointer user_data);
 static void account_period_change(GtkWidget *widget, gpointer user_data);
 static void account_range_change(GtkWidget *widget, gpointer user_data);
@@ -289,9 +289,6 @@ struct account_data *data = user_data;
 }
 
 
-
-
-
 /* these 5 functions are independant from account window */
 Operation *
 operation_get_child_transfer(Operation *src)
@@ -307,7 +304,7 @@ Operation *item;
 	while (list != NULL)
 	{
 		item = list->data;
-		if( item->paymode == PAYMODE_PERSTRANSFERT)
+		if( item->paymode == PAYMODE_PERSTRANSFER)
 		{
 			if( src->date == item->date &&
 			    src->account == item->dst_account &&
@@ -330,12 +327,15 @@ Operation *item;
 
 void operation_warn_transfer(Operation *src, gchar *msg2)
 {
+gchar str_amount[128];
+gchar str_date[128];
+GDate *date;
+Account *acc;
+gchar *accname;
+
+	DB( g_print("(operation) operation_warn_transfer\n") );
 	
-	gchar str_amount[128];
-	gchar str_date[128];
-	GDate *date;
-	Account *acc;
-	
+		
 		mystrfmon(str_amount, 127, src->amount, 0);
 
 		date = g_date_new_julian (src->date);
@@ -344,11 +344,16 @@ void operation_warn_transfer(Operation *src, gchar *msg2)
 		
 		acc = da_acc_get( src->dst_account);
 		
+		//fix 379760
+		accname = _("Unknown");
+		if( acc != NULL )
+			accname = acc->name;
+		
 		//warn the user
-		homebank_message_dialog(GTK_WINDOW(GLOBALS->mainwindow), GTK_MESSAGE_INFO,
+		homebank_message_dialog(NULL, GTK_MESSAGE_INFO,
 			_("No corresponding transfer can be found."),
 			msg2,
-			acc->name,	//account name
+			accname,	//account name
 			str_date,	//date
 			str_amount 	//amount
 			
@@ -361,8 +366,12 @@ void operation_delete_child_transfer(Operation *src)
 {
 Operation *dst;
 
+	DB( g_printf("(operation) delete_child_transfer\n") );
+
 	dst = operation_get_child_transfer( src );
 	
+	DB( g_print(" -> return is %s, %d\n", dst, dst) );
+	
 	if( dst == NULL )
 	{
 		/* warn the useer we have notfound the child internal transfer */
@@ -374,6 +383,8 @@ Operation *dst;
 	}
 	else
 	{
+		DB( g_print("deleting...") );
+		
 		GLOBALS->ope_list = g_list_remove(GLOBALS->ope_list, dst);
 	}
 }
@@ -459,7 +470,7 @@ Account *acc;
 	da_operation_append(newope);
 	if(treeview != NULL) operation_add_treeview(newope, treeview, accnum);
 
-	if(ope->paymode == PAYMODE_PERSTRANSFERT)
+	if(ope->paymode == PAYMODE_PERSTRANSFER)
 	{
 		operation_add_transfer(ope, treeview);
 	}
@@ -588,6 +599,7 @@ GIOChannel *io;
 
 }
 
+
 /*
 ** make an archive with the active operation
 */
@@ -931,7 +943,7 @@ gint *indices;
 	}
 
 	/* deal with transfer to be validated also */
-	if( entry->paymode == PAYMODE_PERSTRANSFERT )
+	if( entry->paymode == PAYMODE_PERSTRANSFER )
 	{
 	Operation *ct;
 		
@@ -1170,7 +1182,7 @@ gboolean result;
 					}
 
 
-					if( ope->paymode == PAYMODE_PERSTRANSFERT )
+					if( ope->paymode == PAYMODE_PERSTRANSFER )
 					{
 					Operation *ct;
 						
@@ -1265,7 +1277,7 @@ gboolean result;
 					}
 
 					/* v3.4: also remove child transfer */
-					if( entry->paymode == PAYMODE_PERSTRANSFERT )
+					if( entry->paymode == PAYMODE_PERSTRANSFER )
 					{
 						operation_delete_child_transfer( entry );
 					}
