@@ -611,6 +611,9 @@ gboolean retval;
 	
 	retval = homebank_util_url_show (link);
 	
+	//todo gtk 2.14
+	//gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (about)), url, GDK_CURRENT_TIME, NULL);
+	
 	if (!retval)
 	{
 		homebank_message_dialog(GTK_WINDOW(GLOBALS->mainwindow), GTK_MESSAGE_INFO,
@@ -1077,7 +1080,7 @@ gint usermode = GPOINTER_TO_INT(user_data);
 					/* todo: update acc flags */
 					acc = da_acc_get(arc->account);
 					acc->flags |= AF_ADDED;
-					if(arc->paymode == PAYMODE_PERSTRANSFERT)
+					if(arc->paymode == PAYMODE_PERSTRANSFER)
 					{
 						acc = da_acc_get(arc->dst_account);
 						acc->flags |= AF_ADDED;
