@@ -65,8 +65,8 @@ enum
 	PAYMODE_CARD,
 	PAYMODE_CHEQUE,
 	PAYMODE_CASH,
-	PAYMODE_BANKTRANSFERT,
-	PAYMODE_PERSTRANSFERT,
+	PAYMODE_BANKTRANSFER,
+	PAYMODE_PERSTRANSFER,
 	NUM_PAYMODE_MAX
 };
 
