@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2008 Maxime DOYEN
+ *  Copyright (C) 1995-2009 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -68,7 +68,7 @@ struct _GtkDateEntryClass
   void (*_gtk_reserved4) (void);
 };
 
-GtkType		gtk_dateentry_get_type(void);
+GType		gtk_dateentry_get_type(void);
 
 GtkWidget	*gtk_dateentry_new(void);
 
