@@ -160,12 +160,21 @@ hb_qif_parser_get_dmy(gchar *string, gint *d, gint *m, gint *y)
 gboolean retval;
 gchar **str_array;
 
+	DB( g_print("hb_qif_parser_get_dmy for '%s'\n", string) );
+
 	retval = FALSE;
 	str_array = g_strsplit (string, "/", 3);
 	if( g_strv_length( str_array ) != 3 )
 	{
 		g_strfreev (str_array);
 		str_array = g_strsplit (string, ".", 3);
+		// fix 371381
+		//todo test
+		if( g_strv_length( str_array ) != 3 )
+		{
+			g_strfreev (str_array);
+			str_array = g_strsplit (string, "-", 3);
+		}
 	}
 
 	if( g_strv_length( str_array ) == 3 )
@@ -377,15 +386,14 @@ QIF_Tran tran = { 0 };
 				
 				hb_string_strip_crlf(tmpstr);
 
-				DB (g_print("\n new QIF line: '%s'\n", tmpstr));
+				DB (g_print("** new QIF line: '%s' **\n", tmpstr));
 
 
 				//start qif parsing
 				if(g_str_has_prefix(tmpstr, "!")) /* !Type: or !Option: or !Account otherwise ignore */
 				{
 					type = hb_qif_parser_get_block_type(tmpstr);
-					DB ( g_print(" ----------------\n") );
-					DB ( g_print("* QIF block: '%s' (type = %d)\n", tmpstr, type) );
+					DB ( g_print("---- QIF block: '%s' (type = %d) ----\n", tmpstr, type) );
 				}
 
 				value = &tmpstr[1];
@@ -526,13 +534,21 @@ QIF_Tran tran = { 0 };
 					{
 					QIF_Tran *newitem;
 
-						tran.account = g_strdup(cur_acc);
+						//fix: 380550
+						if( tran.date )
+						{
+							tran.account = g_strdup(cur_acc);
 
-						DB ( g_print(" storing qif transaction: dat:'%s' amt:%.2f pay:'%s' mem:'%s' cat:'%s' acc:'%s'\n", tran.date, tran.amount, tran.payee, tran.memo, tran.category, tran.account) );
+							DB ( g_print(" storing qif transaction: dat:'%s' amt:%.2f pay:'%s' mem:'%s' cat:'%s' acc:'%s'\n", tran.date, tran.amount, tran.payee, tran.memo, tran.category, tran.account) );
+
+							newitem = da_qif_tran_malloc();
+							da_qif_tran_move(&tran, newitem);
+							da_qif_tran_append(ctx, newitem);
+						}
+
+						//unvalid tran
+						tran.date = 0;
 
-						newitem = da_qif_tran_malloc();
-						da_qif_tran_move(&tran, newitem);
-						da_qif_tran_append(ctx, newitem);
 					}
 				}
 				// end QIF_TRANSACTION
@@ -565,7 +581,7 @@ Operation *item;
 	while (list != NULL)
 	{
 		item = list->data;
-		if( item->paymode == PAYMODE_PERSTRANSFERT)
+		if( item->paymode == PAYMODE_PERSTRANSFER)
 		{
 			if( src->date == item->date &&
 			    src->account == item->dst_account &&
@@ -683,7 +699,7 @@ GList *list = NULL;
 				}
 				
 				newope->dst_account = accitem->key;
-				newope->paymode = PAYMODE_PERSTRANSFERT;
+				newope->paymode = PAYMODE_PERSTRANSFER;
 				
 				
 				g_free(accname);
@@ -834,7 +850,7 @@ size_t rc;
 						// LCategory of transaction/Class of transaction
 						// L[Transfer account]/Class of transaction
 
-					if( trans->paymode == PAYMODE_PERSTRANSFERT && trans->account == item->key)
+					if( trans->paymode == PAYMODE_PERSTRANSFER && trans->account == item->key)
 					{
 						g_string_append_printf (buffer, "L[%s]\n", item->name);
 					}
