@@ -244,7 +244,8 @@ const struct _GeditEncoding *enc;
 
 				g_free(converted_contents);
 		
-				if( isutf8 == true )
+				//fixed: 370922
+				if( isutf8 == TRUE )
 				{
 					
 					retval = enc->charset;
@@ -461,6 +462,8 @@ static gint csvtype[7] = {
 **** OFX part
 **** 
 **** this part is quite weird,but works
+** id is ACCTID
+
 */
 
 static Account * ofx_get_account_by_id(gchar *id)
@@ -656,19 +659,19 @@ Operation *newope;
 				
 				break;
 			case OFX_DEBIT:
-			 		newope->paymode = PAYMODE_BANKTRANSFERT;
+			 		newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_INT:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_DIV:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_FEE:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_SRVCHG:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_DEP:
 					newope->paymode = PAYMODE_CASH;
@@ -680,25 +683,25 @@ Operation *newope;
 					newope->paymode = PAYMODE_CARD;
 				break;
 			case OFX_XFER:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_CHECK:
 					newope->paymode = PAYMODE_CHEQUE;
 				break;
 			case OFX_PAYMENT:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_CASH:
 					newope->paymode = PAYMODE_CASH;
 				break;
 			case OFX_DIRECTDEP:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_DIRECTDEBIT:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_REPEATPMT:
-					newope->paymode = PAYMODE_BANKTRANSFERT;
+					newope->paymode = PAYMODE_BANKTRANSFER;
 				break;
 			case OFX_OTHER:
 					
@@ -2388,8 +2391,20 @@ gint pos;
 
 
 	screen = gtk_window_get_screen(GTK_WINDOW (assistant));
-	width  = gdk_screen_get_width(screen);
-	height = gdk_screen_get_height(screen);
+	// fix #379372 : manage multiple monitor case
+	if( gdk_screen_get_n_monitors(screen) > 1 )
+	{
+	GdkRectangle rect;
+		
+		gdk_screen_get_monitor_geometry(screen, 1, &rect);
+		width = rect.width;
+		height = rect.height;
+	}
+	else
+	{
+		width  = gdk_screen_get_width(screen);
+		height = gdk_screen_get_height(screen);
+	}
 	
 	gtk_window_resize(GTK_WINDOW(assistant), SCOEF*width, SCOEF*height);
 	gtk_window_set_position (GTK_WINDOW (assistant), GTK_WIN_POS_CENTER_ON_PARENT);
