@@ -48,16 +48,15 @@ struct lconv *lc = localeconv();
 
 	DB( g_print("\n** (preferences) monetary unix\n") );
 
-	DB( g_print("mon_decimal_point is utf8: %d", g_utf8_validate(lc->mon_decimal_point, -1, NULL)) );
+	DB( g_print("mon_decimal_point is utf8: %d\n", g_utf8_validate(lc->mon_decimal_point, -1, NULL)) );
 	DB( g_print("mon_decimal_point '%s'\n", lc->mon_decimal_point) );
 	DB( g_print("mon_decimal_point %x %x %x %x\n", lc->mon_decimal_point[0], lc->mon_decimal_point[1], lc->mon_decimal_point[2], lc->mon_decimal_point[3]) );
 
-	DB( g_print("mon_thousands_sep is utf8: %d", g_utf8_validate(lc->mon_thousands_sep, -1, NULL)) );
+	DB( g_print("mon_thousands_sep is utf8: %d\n", g_utf8_validate(lc->mon_thousands_sep, -1, NULL)) );
 	DB( g_print("mon_thousands_sep '%s'\n", lc->mon_thousands_sep) );
 	DB( g_print("mon_thousands_sep %x %x %x %x\n", lc->mon_thousands_sep[0], lc->mon_thousands_sep[1], lc->mon_thousands_sep[2], lc->mon_thousands_sep[3]) );
 
 
-
 	DB( g_print("frac_digits '%d'\n", (gint)lc->frac_digits) );
 
 	DB( g_print("currency_symbol '%s'\n", lc->currency_symbol) );
@@ -92,7 +91,10 @@ struct lconv *lc = localeconv();
 	DB( g_print(" -> grouping_char: '%s'\n", PREFS->base_cur.grouping_char) );
 	
 	PREFS->base_cur.frac_digits   = lc->frac_digits;
-	
+	//fix 378992
+	if( lc->frac_digits > MAX_FRAC_DIGIT )
+		PREFS->base_cur.frac_digits = MAX_FRAC_DIGIT;
+
 
 #else
 	#ifdef G_OS_WIN32
