@@ -250,6 +250,24 @@ gint nbmonth;
 	return(nbmonth);
 }
 
+static gdouble budget_compute_decay(gdouble budget, gdouble spent)
+{
+gdouble decay;
+
+	//original formula
+	//decay = ABS(budget) - ABS(spent);
+	
+	decay = budget - spent;
+	//then the decay sign is determined by budget sign
+	if( budget < 0 )
+		decay *= -1;
+
+	return decay;
+}
+
+
+
+
 
 static void repbudget_date_change(GtkWidget *widget, gpointer user_data)
 {
@@ -443,7 +461,7 @@ GtkTreeIter  iter;
 
 
 			//filter here
-			if( !(ope->flags & OF_REMIND) && ope->date >= data->mindate && ope->date <= data->maxdate)
+			if( !(ope->flags & OF_REMIND) && (ope->date >= data->mindate) && (ope->date <= data->maxdate))
 			{
 			gint pos = 0;
 
@@ -550,7 +568,7 @@ gint nbmonth = 1;
 
 			//debug
 			#if MYDEBUG == 1
-			/*
+			
 			gint k;
 
 			g_print("--------\n");
@@ -559,7 +577,7 @@ gint nbmonth = 1;
 			for(k=0;k<13;k++)
 				g_print( "%d[%.2f] ", k, entry->budget[k]);
 			g_print("\n");
-				*/
+				
 			#endif
 
 
@@ -581,10 +599,12 @@ gint nbmonth = 1;
 					break;
 			}
 			
+			DB( g_print(" ** budget for %d '%s'\n", entry->key, entry->name) );
+			
 			// same value each month ?
 			if(!(entry->flags & GF_CUSTOM))
 			{
-				//DB( g_print(" cat %s -> monthly %.2f\n", name, entry->budget[0]) );
+				//DB( g_print(" cat %s -> monthly %.2f\n", entry->name, entry->budget[0]) );
 				tmp_budget[pos] += entry->budget[0]*nbmonth;
 				tmp_hasbudget[i] += entry->budget[0]*nbmonth;
 			}
@@ -594,14 +614,12 @@ gint nbmonth = 1;
 			gint month = getmonth(mindate);
 			gint j;
 
-				//DB( g_print(" cat '%s' -> custom month=%ld nbmonth=%ld\n", name, month, nbmonth) );
-
 				for(j=0;j<nbmonth;j++)
 				{
-					DB( g_print(" %d, cat %s -> custom j=%ld month=%ld budg=%.2f\n", j, entry->name, month, tmp_budget[pos]) );
+					DB( g_print(" %d, cat %s -> custom j=%ld month=%ld budg=%.2f\n", j, entry->name, month, entry->budget[month]) );
 
 					tmp_budget[pos] += entry->budget[month];
-					tmp_budget[i] += entry->budget[month];
+					tmp_hasbudget[i] += entry->budget[month];
 					month++;
 					if(month > 12) month = 1;
 				}
@@ -611,7 +629,7 @@ gint nbmonth = 1;
 			#if MYDEBUG == 1
 			if( tmp_budget[pos] )
 			{
-				g_print(" -> cat %d %s, budg[%d]=%.2f\n", entry->key, entry->name, pos, tmp_budget[pos]);
+				g_print(" -> cat %d %s, budg[%d]=%.2f hasbudg[%d]\n", entry->key, entry->name, pos, tmp_budget[pos], i, tmp_hasbudget[i]);
 			}
 
 			#endif
@@ -629,14 +647,18 @@ gint nbmonth = 1;
 		Operation *ope = list->data;
 		Account *acc;
 
-			DB( g_print("%d, get ope: %s :: acc=%d, cat=%d, mnt=%.2f\n", i, ope->wording, ope->account, ope->category, ope->amount) );
+			//DB( g_print("%d, get ope: %s :: acc=%d, cat=%d, mnt=%.2f\n", i, ope->wording, ope->account, ope->category, ope->amount) );
 
 			acc = da_acc_get(ope->account);
 			if(acc != NULL)
 			{
 				if((acc->flags & AF_CLOSED)) goto next1;
 				if(!(acc->flags & AF_BUDGET)) goto next1;
-				if( tmp_hasbudget[ope->category] == 0 ) goto next1;
+				if( tmp_hasbudget[ope->category] == 0 )
+				{
+					DB( g_print(" -> no budget for cat %d\n", ope->category) );
+					goto next1;
+				}
 
 				if( !(ope->flags & OF_REMIND) && ope->date >= mindate && ope->date <= maxdate)
 				{
@@ -657,8 +679,12 @@ gint nbmonth = 1;
 							break;
 					}
 
+					DB( g_print(" -> affecting %.2f to cat %d\n", ope->amount, pos) );					
+
 					if( pos >= 0)
+					{
 						tmp_spent[pos] += ope->amount;
+					}
 				}
 			}	
 
@@ -734,7 +760,11 @@ next1:
 
 				if(tmp_budget[pos] || tmp_spent[pos])
 				{
-					DB( g_print(" inserting %i, %s, %.2f %.2f %.2f\n", i, name, tmp_spent[pos], tmp_budget[pos], tmp_spent[pos] - tmp_budget[pos]) );
+				gdouble decay;
+				
+					decay = budget_compute_decay(tmp_budget[pos], tmp_spent[pos]);
+				
+					DB( g_print(" inserting %i, %s, %.2f %.2f %.2f\n", i, name, tmp_spent[pos], tmp_budget[pos], decay) );
 
 					gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 			 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
@@ -743,7 +773,7 @@ next1:
 						LST_BUDGET_NAME, name,
 						LST_BUDGET_SPENT, tmp_spent[pos],
 						LST_BUDGET_BUDGET, tmp_budget[pos],
-						LST_BUDGET_DECAY, ABS(tmp_budget[pos]) - ABS(tmp_spent[pos]),
+						LST_BUDGET_DECAY, decay,
 						-1);
 
 					data->total_spent  += tmp_spent[pos];
@@ -775,7 +805,7 @@ next1:
 		else
 			gtk_chart_set_datas(GTK_CHART(data->RE_bar), model, column);
 
-		gtk_chart_set_title(GTK_CHART(data->RE_bar), _(CYA_BUDGETSELECT[tmpkind]));
+		gtk_chart_set_title(GTK_CHART(data->RE_bar), _(CYA_BUDGETSELECT[tmpview]));
 
 		
 		
@@ -829,7 +859,7 @@ gboolean minor;
 
 	hb_label_set_colvalue(GTK_LABEL(data->TX_total[0]), data->total_spent, minor);
 	hb_label_set_colvalue(GTK_LABEL(data->TX_total[1]), data->total_budget, minor);
-	hb_label_set_colvalue(GTK_LABEL(data->TX_total[2]), ABS(data->total_budget) - ABS(data->total_spent), minor);
+	hb_label_set_colvalue(GTK_LABEL(data->TX_total[2]), budget_compute_decay(data->total_budget, data->total_spent), minor);
 
 }
 
