@@ -544,86 +544,89 @@ GtkTreeIter  iter;
 			//DB( g_print(" get %s\n", ope->ope_Word) );
 
 			//filter here
-			if(filter_test(data->filter, ope) == 1)
+			if( !(ope->flags & OF_REMIND) )
 			{
-			gint pos = 0;
-
-				if( tmpfor != STAT_TAG )
+				if(filter_test(data->filter, ope) == 1)
 				{
+				gint pos = 0;
 
-					switch(tmpfor)
-					{
-						case STAT_CATEGORY:
-							{
-							Category *catentry = da_cat_get(ope->category);
-								if(catentry)
-									pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
-							}
-							break;
-						case STAT_SUBCATEGORY:
-							pos = ope->category;
-							break;
-						case STAT_PAYEE:
-							pos = ope->payee;
-							break;
-
-						case STAT_MONTH:
-							pos = DateInPer(data->filter->mindate, ope->date);
-							break;
-						case STAT_YEAR:
-							pos = DateInYear(data->filter->mindate, ope->date);
-							break;
-					}
-
-					//insert
-					if( pos == active )
+					if( tmpfor != STAT_TAG )
 					{
 
-				    	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-			     		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-							LST_DSPOPE_DATAS, ope,
-							-1);
-
-					/*
-					if(ApplyFilter(&data->flt, ope))
-					{
-						DoMethod(data->LV_detail, MUIM_NList_InsertSingle, ope, MUIV_NList_Insert_Bottom);
-					}
-					*/
-					}
-
-
-				}
-				else
-				/* the TAG process is particular */
-				{
-					if(ope->tags != NULL)
-					{
-					guint32 *tptr = ope->tags;
-					
-						while(*tptr)
+						switch(tmpfor)
 						{
-							pos = *tptr - 1;
-	
-							DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) ); 
+							case STAT_CATEGORY:
+								{
+								Category *catentry = da_cat_get(ope->category);
+									if(catentry)
+										pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
+								}
+								break;
+							case STAT_SUBCATEGORY:
+								pos = ope->category;
+								break;
+							case STAT_PAYEE:
+								pos = ope->payee;
+								break;
 
-							if( pos == active )
-							{
-						    	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-					     		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-									LST_DSPOPE_DATAS, ope,
-									-1);
+							case STAT_MONTH:
+								pos = DateInPer(data->filter->mindate, ope->date);
+								break;
+							case STAT_YEAR:
+								pos = DateInYear(data->filter->mindate, ope->date);
+								break;
+						}
+
+						//insert
+						if( pos == active )
+						{
+
+							gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+					 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+								LST_DSPOPE_DATAS, ope,
+								-1);
+
+						/*
+						if(ApplyFilter(&data->flt, ope))
+						{
+							DoMethod(data->LV_detail, MUIM_NList_InsertSingle, ope, MUIV_NList_Insert_Bottom);
+						}
+						*/
+						}
 
-							}
-	
-							tptr++;
-						} 	
 
 					}
+					else
+					/* the TAG process is particular */
+					{
+						if(ope->tags != NULL)
+						{
+						guint32 *tptr = ope->tags;
+					
+							while(*tptr)
+							{
+								pos = *tptr - 1;
+	
+								DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) ); 
+
+								if( pos == active )
+								{
+									gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+							 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+										LST_DSPOPE_DATAS, ope,
+										-1);
+
+								}
+	
+								tptr++;
+							} 	
+
+						}
+					}
+
+
+
 				}
-
-
-
 			}
 			list = g_list_next(list);
 		}
@@ -828,88 +831,91 @@ gdouble exprate, incrate, balrate;
 			//debug
 			DB( g_print("** testing '%s', cat=%d==> %d\n", ope->wording, ope->category, filter_test(data->filter, ope)) );
 
-
-			if(filter_test(data->filter, ope) == 1)
+			if( !(ope->flags & OF_REMIND) )
 			{
-			guint32 pos = 0;
 
-				if( tmpfor != STAT_TAG )
+				if( (filter_test(data->filter, ope) == 1) )
 				{
-					switch(tmpfor)
-					{
-						case STAT_CATEGORY:
-							{
-							Category *catentry = da_cat_get(ope->category);
-								if(catentry)
-									pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
-							}
-							break;
-						case STAT_SUBCATEGORY:
-							pos = ope->category;
-							break;
-						case STAT_PAYEE:
-							pos = ope->payee;
-							break;
-						case STAT_MONTH:
-							pos = DateInPer(from, ope->date);
-							break;
-						case STAT_YEAR:
-							pos = DateInYear(from, ope->date);
-							break;
-					}
+				guint32 pos = 0;
 
-					if(pos >= 0)
-					{// add the amount
-						if(ope->amount > 0)
-						{
-							tmp_income[pos] += ope->amount;
-							data->total_income  += ope->amount;
-						}
-						else
-						{
-							tmp_expense[pos] += ope->amount;
-							//data->total_expense += ABS(ope->amount);
-							data->total_expense += ope->amount;
-						}
-					}
-				}
-				else
-				/* the TAG process is particular */
-				{
-					if(ope->tags != NULL)
+					if( tmpfor != STAT_TAG )
 					{
-					guint32 *tptr = ope->tags;
-					
-						while(*tptr)
+						switch(tmpfor)
 						{
-							pos = *tptr - 1;
-	
-							DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) ); 
-	
+							case STAT_CATEGORY:
+								{
+								Category *catentry = da_cat_get(ope->category);
+									if(catentry)
+										pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
+								}
+								break;
+							case STAT_SUBCATEGORY:
+								pos = ope->category;
+								break;
+							case STAT_PAYEE:
+								pos = ope->payee;
+								break;
+							case STAT_MONTH:
+								pos = DateInPer(from, ope->date);
+								break;
+							case STAT_YEAR:
+								pos = DateInYear(from, ope->date);
+								break;
+						}
+
+						if(pos >= 0)
+						{// add the amount
 							if(ope->amount > 0)
 							{
 								tmp_income[pos] += ope->amount;
+								data->total_income  += ope->amount;
 							}
 							else
 							{
 								tmp_expense[pos] += ope->amount;
-							}							
-							tptr++;
-						} 	
-
-						data->total_income  += ope->amount;
-						data->total_expense += ope->amount;
-
+								//data->total_expense += ABS(ope->amount);
+								data->total_expense += ope->amount;
+							}
+						}
 					}
+					else
+					/* the TAG process is particular */
+					{
+						if(ope->tags != NULL)
+						{
+						guint32 *tptr = ope->tags;
+					
+							while(*tptr)
+							{
+								pos = *tptr - 1;
+	
+								DB( g_print(" -> storing tag %d %.2f\n", pos, ope->amount) ); 
+	
+								if(ope->amount > 0)
+								{
+									tmp_income[pos] += ope->amount;
+								}
+								else
+								{
+									tmp_expense[pos] += ope->amount;
+								}							
+								tptr++;
+							} 	
+
+							data->total_income  += ope->amount;
+							data->total_expense += ope->amount;
+
+						}
+					}
+
+
+
+					// fix total according to selection
+					//if(tmpkind==0 && !tmp_expense[pos]) { data->total_income  -= ope->amount; }
+					//if(tmpkind==1 && !tmp_income[pos] ) { data->total_expense -= ope->amount; }
+
+
 				}
-
-
-
-				// fix total according to selection
-				//if(tmpkind==0 && !tmp_expense[pos]) { data->total_income  -= ope->amount; }
-				//if(tmpkind==1 && !tmp_income[pos] ) { data->total_expense -= ope->amount; }
-
-
 			}
 			list = g_list_next(list);
 		}
@@ -1285,7 +1291,7 @@ static void statistic_setup(struct statistic_data *data)
 	
 	/* 3.4 : make int transfer out of stats */
 	data->filter->option[FILTER_PAYMODE] = 1;
-	data->filter->paymode[PAYMODE_PERSTRANSFERT] = FALSE;
+	data->filter->paymode[PAYMODE_PERSTRANSFER] = FALSE;
 
 	/* if ope get date bounds */
 	if(g_list_length(GLOBALS->ope_list) > 0)
