@@ -445,10 +445,10 @@ gchar *string;
 	type = (entry->flags & GF_INCOME) ? '+' : '-';
 
 	#if MYDEBUG
-	string = g_strdup_printf ("%d > [%d] %s [%c]", entry->key, entry->parent, name, type );
+	string = g_markup_printf_escaped ("%d > [%d] %s [%c]", entry->key, entry->parent, name, type );
 	#else
 	if( entry->parent == 0 )
-		string = g_strdup(name);
+		string = g_markup_printf_escaped("%s", name);
 	else
 		string = g_markup_printf_escaped("<i>%s</i>", name);
 		//string = g_strdup_printf(" - %s", name);
